@@ -29,7 +29,7 @@ import setproctitle
 from imdb import IMDb
 from unidecode import unidecode
 
-from common import Manager, Provider, BADGES, MOVIES_GROUP, PROVIDERS_PATH, SERIES_GROUP, TV_GROUP,\
+from common import Manager, Provider, MOVIES_GROUP, PROVIDERS_PATH, SERIES_GROUP, TV_GROUP,\
     async_function, idle_function
 
 
@@ -70,6 +70,13 @@ AUDIO_SAMPLE_FORMATS = {
     "dblp": "double, planar",
 }
 
+COUNTRY_CODES = {}
+with open("/usr/share/hypnotix/countries.list") as f:
+    for line in f:
+        line = line.strip()
+        code, name = line.split(":")
+        COUNTRY_CODES[name] = code
+
 class ChannelWidget(Gtk.ListBoxRow):
     """ A custom widget for displaying and holding channel data. """
 
@@ -391,18 +398,30 @@ class MainWindow:
         surf = self.get_surface_for_file(filename, width, height)
         return Gtk.Image.new_from_surface(surf)
 
+    def add_flag(self, code, box):
+        path = f"/usr/share/circle-flags-svg/{code.lower()}.svg"
+        if os.path.exists(path):
+            try:
+                image = self.get_surf_based_image(path, -1, 32)
+                box.pack_start(image, False, False, 0)
+            except Exception as e:
+                print("Could not load flag", path)
+                print(e)
+        else:
+            print("Couldn't find flag", path)
+
     def add_badge(self, word, box, added_words):
         if word not in added_words:
             for extension in ["svg", "png"]:
-                badge = "/usr/share/hypnotix/pictures/badges/%s.%s" % (word, extension)
-                if os.path.exists(badge):
+                path = "/usr/share/hypnotix/pictures/badges/%s.%s" % (word, extension)
+                if os.path.exists(path):
                     try:
-                        image = self.get_surf_based_image(badge, -1, 32)
+                        image = self.get_surf_based_image(path, -1, 32)
                         box.pack_start(image, False, False, 0)
                         added_words.append(word)
                         break
                     except Exception as e:
-                        print("Could not load badge", badge)
+                        print("Could not load badge", path)
                         print(e)
 
     def show_groups(self, widget, content_type):
@@ -428,10 +447,20 @@ class MainWindow:
             box = Gtk.Box()
             name = group.name.lower().replace("(", " ").replace(")", " ")
             added_words = []
+
+            found_flag = False
+            for country_name in COUNTRY_CODES.keys():
+                if country_name.lower() in group.name.lower():
+                    found_flag = True
+                    self.add_flag(COUNTRY_CODES[country_name], box)
+                    break
+
+            if not found_flag:
+                print(f"No flag found for: {group.name}")
+
             for word in name.split():
                 self.add_badge(word, box, added_words)
-                if word in BADGES.keys():
-                    self.add_badge(BADGES[word], box, added_words)
+
             box.pack_start(label, False, False, 0)
             box.set_spacing(6)
             button.add(box)
